/*
 * Graphic driver for openKropki
 * Copyright (C) 2014, 2015, Mateusz Viste
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef drv_gra_h_sentinel
#define drv_gra_h_sentinel

#define GRA_FULLSCREEN 1

struct gra_sprite;

/* init the video subsystem */
int gra_init(int width, int height, int flags, char *windowtitle, unsigned char *titleicon, long titleicon_len);

/* close and clean up the graphic subsystem */
void gra_close(void);

/* clears the screen (should be used at each screen refresh iteration) */
void gra_clear(void);

/* switch the application fullscreen on/off */
void gra_switchfullscreen(void);

void gra_drawpartsprite(struct gra_sprite *sprite, int srcx, int srcy, int srcwidth, int srcheight, int dstx, int dsty);

void gra_drawsprite_alpha(struct gra_sprite *sprite, int x, int y, int alpha);

void gra_drawsprite(struct gra_sprite *sprite, int x, int y);

void gra_refresh(void);

/* loads a gziped bmp image from memory and returns a surface */
struct gra_sprite *gra_loadgzbmp(unsigned char *memgz, long memgzlen);

void loadSpriteSheet(struct gra_sprite **sprites, int width, int height, int itemcount, void *memptr, int memlen);

int gra_getspritewidth(struct gra_sprite *sprite);

int gra_getspriteheight(struct gra_sprite *sprite);

int gra_drawrect(int x, int y, int width, int height, int r, int g, int b, int a, int fillflag);

void gra_drawline(int x1, int y1, int x2, int y2, int thickness, int r, int g, int b, int a);

void gra_circle(int x, int y, int rad, int r, int g, int b, int a, int fillflag);

struct gra_sprite *gra_text2sprite(char *message, unsigned char *font_ttf, long font_ttf_len, int fontSize, int r, int g, int b, int a);

void gra_freesprite(struct gra_sprite *spr);

void gra_getwinsize(int *w, int *h);

#endif
